Dash Components
---------------

Several custom Dash components are distributed with Crystal Toolkit to enable
the functionality of Crystal Toolkit apps.

These can be used and imported as any other Plotly Dash component.

Simple3DScene
~~~~~~~~~~~~~

The intent of this component is to provide easy three-dimensional rendering of
"scenes" containing geometric primitives, such as cylinders or spheres.

Above all, this component is designed for *simple* use. It is not designed to
compete with full scene graph implementations such as VTK or Three.js. If you
want advanced usage, you should use these very powerful and well-documented
libraries directly. Simple3DScene does use Three.js behind the scenes to power
its functionality.

Link to documentation for creating ``Scene`` objects inside Python.

Link to ``Simple3DScene`` Dash component to render resulting ``Scene`` object.
